Hover tests

## Hover (mouse{over,out,enter,leave}) Tests

Be sure to try moving the mouse out of the browser via the left side on each test.

.hover() in/out: 0 / 0
Mouse over here should NOT trigger the counter.
Live enter/leave: 0 / 0
Mouse over here should NOT trigger the counter.
Delegated enter/leave: 0 / 0
Mouse over here should NOT trigger the counter.
Bind over/out: 0 / 0
Mouse over here SHOULD trigger the counter.
Live over/out: 0 / 0
Mouse over here SHOULD trigger the counter.
Delegated over/out: 0 / 0
Mouse over here SHOULD trigger the counter.